@@ -19,28 +19,28 @@ from botocore.client import ClientMeta
 
 from .paginator import DescribeAccountLimitsPaginator, DescribeLoadBalancersPaginator
 from .type_defs import (
-    AddAvailabilityZonesOutputTypeDef,
-    ApplySecurityGroupsToLoadBalancerOutputTypeDef,
-    AttachLoadBalancerToSubnetsOutputTypeDef,
-    ConfigureHealthCheckOutputTypeDef,
-    CreateAccessPointOutputTypeDef,
-    DeregisterEndPointsOutputTypeDef,
-    DescribeAccessPointsOutputTypeDef,
-    DescribeAccountLimitsOutputTypeDef,
-    DescribeEndPointStateOutputTypeDef,
-    DescribeLoadBalancerAttributesOutputTypeDef,
-    DescribeLoadBalancerPoliciesOutputTypeDef,
-    DescribeLoadBalancerPolicyTypesOutputTypeDef,
-    DescribeTagsOutputTypeDef,
-    DetachLoadBalancerFromSubnetsOutputTypeDef,
+    AddAvailabilityZonesOutputResponseTypeDef,
+    ApplySecurityGroupsToLoadBalancerOutputResponseTypeDef,
+    AttachLoadBalancerToSubnetsOutputResponseTypeDef,
+    ConfigureHealthCheckOutputResponseTypeDef,
+    CreateAccessPointOutputResponseTypeDef,
+    DeregisterEndPointsOutputResponseTypeDef,
+    DescribeAccessPointsOutputResponseTypeDef,
+    DescribeAccountLimitsOutputResponseTypeDef,
+    DescribeEndPointStateOutputResponseTypeDef,
+    DescribeLoadBalancerAttributesOutputResponseTypeDef,
+    DescribeLoadBalancerPoliciesOutputResponseTypeDef,
+    DescribeLoadBalancerPolicyTypesOutputResponseTypeDef,
+    DescribeTagsOutputResponseTypeDef,
+    DetachLoadBalancerFromSubnetsOutputResponseTypeDef,
     HealthCheckTypeDef,
     InstanceTypeDef,
     ListenerTypeDef,
     LoadBalancerAttributesTypeDef,
-    ModifyLoadBalancerAttributesOutputTypeDef,
+    ModifyLoadBalancerAttributesOutputResponseTypeDef,
     PolicyAttributeTypeDef,
-    RegisterEndPointsOutputTypeDef,
-    RemoveAvailabilityZonesOutputTypeDef,
+    RegisterEndPointsOutputResponseTypeDef,
+    RemoveAvailabilityZonesOutputResponseTypeDef,
     TagKeyOnlyTypeDef,
     TagTypeDef,
 )
@@ -91,7 +91,7 @@ class Exceptions:
 
 class ElasticLoadBalancingClient:
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/elb.html#ElasticLoadBalancing.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elb.html#ElasticLoadBalancing.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html)
     """
 
@@ -100,37 +100,50 @@ class ElasticLoadBalancingClient:
 
     def add_tags(self, *, LoadBalancerNames: List[str], Tags: List["TagTypeDef"]) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/elb.html#ElasticLoadBalancing.Client.add_tags)
+        Adds the specified tags to the specified load balancer.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elb.html#ElasticLoadBalancing.Client.add_tags)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#add_tags)
         """
 
     def apply_security_groups_to_load_balancer(
         self, *, LoadBalancerName: str, SecurityGroups: List[str]
-    ) -> ApplySecurityGroupsToLoadBalancerOutputTypeDef:
+    ) -> ApplySecurityGroupsToLoadBalancerOutputResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/elb.html#ElasticLoadBalancing.Client.apply_security_groups_to_load_balancer)
+        Associates one or more security groups with your load balancer in a virtual
+        private cloud (VPC).
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elb.html#ElasticLoadBalancing.Client.apply_security_groups_to_load_balancer)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#apply_security_groups_to_load_balancer)
         """
 
     def attach_load_balancer_to_subnets(
         self, *, LoadBalancerName: str, Subnets: List[str]
-    ) -> AttachLoadBalancerToSubnetsOutputTypeDef:
+    ) -> AttachLoadBalancerToSubnetsOutputResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/elb.html#ElasticLoadBalancing.Client.attach_load_balancer_to_subnets)
+        Adds one or more subnets to the set of configured subnets for the specified load
+        balancer.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elb.html#ElasticLoadBalancing.Client.attach_load_balancer_to_subnets)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#attach_load_balancer_to_subnets)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/elb.html#ElasticLoadBalancing.Client.can_paginate)
+        Check if an operation can be paginated.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elb.html#ElasticLoadBalancing.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#can_paginate)
         """
 
     def configure_health_check(
         self, *, LoadBalancerName: str, HealthCheck: "HealthCheckTypeDef"
-    ) -> ConfigureHealthCheckOutputTypeDef:
+    ) -> ConfigureHealthCheckOutputResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/elb.html#ElasticLoadBalancing.Client.configure_health_check)
+        Specifies the health check settings to use when evaluating the health state of
+        your EC2 instances.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elb.html#ElasticLoadBalancing.Client.configure_health_check)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#configure_health_check)
         """
 
@@ -138,7 +151,10 @@ class ElasticLoadBalancingClient:
         self, *, LoadBalancerName: str, PolicyName: str, CookieName: str
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/elb.html#ElasticLoadBalancing.Client.create_app_cookie_stickiness_policy)
+        Generates a stickiness policy with sticky session lifetimes that follow that of
+        an application-generated cookie.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elb.html#ElasticLoadBalancing.Client.create_app_cookie_stickiness_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#create_app_cookie_stickiness_policy)
         """
 
@@ -146,7 +162,10 @@ class ElasticLoadBalancingClient:
         self, *, LoadBalancerName: str, PolicyName: str, CookieExpirationPeriod: int = None
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/elb.html#ElasticLoadBalancing.Client.create_lb_cookie_stickiness_policy)
+        Generates a stickiness policy with sticky session lifetimes controlled by the
+        lifetime of the browser (user-agent) or a specified expiration period.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elb.html#ElasticLoadBalancing.Client.create_lb_cookie_stickiness_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#create_lb_cookie_stickiness_policy)
         """
 
@@ -160,9 +179,11 @@ class ElasticLoadBalancingClient:
         SecurityGroups: List[str] = None,
         Scheme: str = None,
         Tags: List["TagTypeDef"] = None
-    ) -> CreateAccessPointOutputTypeDef:
+    ) -> CreateAccessPointOutputResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/elb.html#ElasticLoadBalancing.Client.create_load_balancer)
+        Creates a Classic Load Balancer.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elb.html#ElasticLoadBalancing.Client.create_load_balancer)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#create_load_balancer)
         """
 
@@ -170,7 +191,9 @@ class ElasticLoadBalancingClient:
         self, *, LoadBalancerName: str, Listeners: List["ListenerTypeDef"]
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/elb.html#ElasticLoadBalancing.Client.create_load_balancer_listeners)
+        Creates one or more listeners for the specified load balancer.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elb.html#ElasticLoadBalancing.Client.create_load_balancer_listeners)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#create_load_balancer_listeners)
         """
 
@@ -180,16 +203,20 @@ class ElasticLoadBalancingClient:
         LoadBalancerName: str,
         PolicyName: str,
         PolicyTypeName: str,
-        PolicyAttributes: List[PolicyAttributeTypeDef] = None
+        PolicyAttributes: List["PolicyAttributeTypeDef"] = None
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/elb.html#ElasticLoadBalancing.Client.create_load_balancer_policy)
+        Creates a policy with the specified attributes for the specified load balancer.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elb.html#ElasticLoadBalancing.Client.create_load_balancer_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#create_load_balancer_policy)
         """
 
     def delete_load_balancer(self, *, LoadBalancerName: str) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/elb.html#ElasticLoadBalancing.Client.delete_load_balancer)
+        Deletes the specified load balancer.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elb.html#ElasticLoadBalancing.Client.delete_load_balancer)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#delete_load_balancer)
         """
 
@@ -197,7 +224,9 @@ class ElasticLoadBalancingClient:
         self, *, LoadBalancerName: str, LoadBalancerPorts: List[int]
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/elb.html#ElasticLoadBalancing.Client.delete_load_balancer_listeners)
+        Deletes the specified listeners from the specified load balancer.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elb.html#ElasticLoadBalancing.Client.delete_load_balancer_listeners)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#delete_load_balancer_listeners)
         """
 
@@ -205,93 +234,123 @@ class ElasticLoadBalancingClient:
         self, *, LoadBalancerName: str, PolicyName: str
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/elb.html#ElasticLoadBalancing.Client.delete_load_balancer_policy)
+        Deletes the specified policy from the specified load balancer.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elb.html#ElasticLoadBalancing.Client.delete_load_balancer_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#delete_load_balancer_policy)
         """
 
     def deregister_instances_from_load_balancer(
         self, *, LoadBalancerName: str, Instances: List["InstanceTypeDef"]
-    ) -> DeregisterEndPointsOutputTypeDef:
+    ) -> DeregisterEndPointsOutputResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/elb.html#ElasticLoadBalancing.Client.deregister_instances_from_load_balancer)
+        Deregisters the specified instances from the specified load balancer.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elb.html#ElasticLoadBalancing.Client.deregister_instances_from_load_balancer)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#deregister_instances_from_load_balancer)
         """
 
     def describe_account_limits(
         self, *, Marker: str = None, PageSize: int = None
-    ) -> DescribeAccountLimitsOutputTypeDef:
+    ) -> DescribeAccountLimitsOutputResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/elb.html#ElasticLoadBalancing.Client.describe_account_limits)
+        Describes the current Elastic Load Balancing resource limits for your AWS
+        account.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elb.html#ElasticLoadBalancing.Client.describe_account_limits)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#describe_account_limits)
         """
 
     def describe_instance_health(
         self, *, LoadBalancerName: str, Instances: List["InstanceTypeDef"] = None
-    ) -> DescribeEndPointStateOutputTypeDef:
+    ) -> DescribeEndPointStateOutputResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/elb.html#ElasticLoadBalancing.Client.describe_instance_health)
+        Describes the state of the specified instances with respect to the specified
+        load balancer.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elb.html#ElasticLoadBalancing.Client.describe_instance_health)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#describe_instance_health)
         """
 
     def describe_load_balancer_attributes(
         self, *, LoadBalancerName: str
-    ) -> DescribeLoadBalancerAttributesOutputTypeDef:
+    ) -> DescribeLoadBalancerAttributesOutputResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/elb.html#ElasticLoadBalancing.Client.describe_load_balancer_attributes)
+        Describes the attributes for the specified load balancer.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elb.html#ElasticLoadBalancing.Client.describe_load_balancer_attributes)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#describe_load_balancer_attributes)
         """
 
     def describe_load_balancer_policies(
         self, *, LoadBalancerName: str = None, PolicyNames: List[str] = None
-    ) -> DescribeLoadBalancerPoliciesOutputTypeDef:
+    ) -> DescribeLoadBalancerPoliciesOutputResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/elb.html#ElasticLoadBalancing.Client.describe_load_balancer_policies)
+        Describes the specified policies.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elb.html#ElasticLoadBalancing.Client.describe_load_balancer_policies)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#describe_load_balancer_policies)
         """
 
     def describe_load_balancer_policy_types(
         self, *, PolicyTypeNames: List[str] = None
-    ) -> DescribeLoadBalancerPolicyTypesOutputTypeDef:
+    ) -> DescribeLoadBalancerPolicyTypesOutputResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/elb.html#ElasticLoadBalancing.Client.describe_load_balancer_policy_types)
+        Describes the specified load balancer policy types or all load balancer policy
+        types.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elb.html#ElasticLoadBalancing.Client.describe_load_balancer_policy_types)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#describe_load_balancer_policy_types)
         """
 
     def describe_load_balancers(
         self, *, LoadBalancerNames: List[str] = None, Marker: str = None, PageSize: int = None
-    ) -> DescribeAccessPointsOutputTypeDef:
+    ) -> DescribeAccessPointsOutputResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/elb.html#ElasticLoadBalancing.Client.describe_load_balancers)
+        Describes the specified the load balancers.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elb.html#ElasticLoadBalancing.Client.describe_load_balancers)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#describe_load_balancers)
         """
 
-    def describe_tags(self, *, LoadBalancerNames: List[str]) -> DescribeTagsOutputTypeDef:
+    def describe_tags(self, *, LoadBalancerNames: List[str]) -> DescribeTagsOutputResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/elb.html#ElasticLoadBalancing.Client.describe_tags)
+        Describes the tags associated with the specified load balancers.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elb.html#ElasticLoadBalancing.Client.describe_tags)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#describe_tags)
         """
 
     def detach_load_balancer_from_subnets(
         self, *, LoadBalancerName: str, Subnets: List[str]
-    ) -> DetachLoadBalancerFromSubnetsOutputTypeDef:
+    ) -> DetachLoadBalancerFromSubnetsOutputResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/elb.html#ElasticLoadBalancing.Client.detach_load_balancer_from_subnets)
+        Removes the specified subnets from the set of configured subnets for the load
+        balancer.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elb.html#ElasticLoadBalancing.Client.detach_load_balancer_from_subnets)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#detach_load_balancer_from_subnets)
         """
 
     def disable_availability_zones_for_load_balancer(
         self, *, LoadBalancerName: str, AvailabilityZones: List[str]
-    ) -> RemoveAvailabilityZonesOutputTypeDef:
+    ) -> RemoveAvailabilityZonesOutputResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/elb.html#ElasticLoadBalancing.Client.disable_availability_zones_for_load_balancer)
+        Removes the specified Availability Zones from the set of Availability Zones for
+        the specified load balancer in EC2-Classic or a default VPC.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elb.html#ElasticLoadBalancing.Client.disable_availability_zones_for_load_balancer)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#disable_availability_zones_for_load_balancer)
         """
 
     def enable_availability_zones_for_load_balancer(
         self, *, LoadBalancerName: str, AvailabilityZones: List[str]
-    ) -> AddAvailabilityZonesOutputTypeDef:
+    ) -> AddAvailabilityZonesOutputResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/elb.html#ElasticLoadBalancing.Client.enable_availability_zones_for_load_balancer)
+        Adds the specified Availability Zones to the set of Availability Zones for the
+        specified load balancer in EC2-Classic or a default VPC.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elb.html#ElasticLoadBalancing.Client.enable_availability_zones_for_load_balancer)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#enable_availability_zones_for_load_balancer)
         """
 
@@ -303,31 +362,39 @@ class ElasticLoadBalancingClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/elb.html#ElasticLoadBalancing.Client.generate_presigned_url)
+        Generate a presigned url given a client, its method, and arguments.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elb.html#ElasticLoadBalancing.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#generate_presigned_url)
         """
 
     def modify_load_balancer_attributes(
         self, *, LoadBalancerName: str, LoadBalancerAttributes: "LoadBalancerAttributesTypeDef"
-    ) -> ModifyLoadBalancerAttributesOutputTypeDef:
+    ) -> ModifyLoadBalancerAttributesOutputResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/elb.html#ElasticLoadBalancing.Client.modify_load_balancer_attributes)
+        Modifies the attributes of the specified load balancer.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elb.html#ElasticLoadBalancing.Client.modify_load_balancer_attributes)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#modify_load_balancer_attributes)
         """
 
     def register_instances_with_load_balancer(
         self, *, LoadBalancerName: str, Instances: List["InstanceTypeDef"]
-    ) -> RegisterEndPointsOutputTypeDef:
+    ) -> RegisterEndPointsOutputResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/elb.html#ElasticLoadBalancing.Client.register_instances_with_load_balancer)
+        Adds the specified instances to the specified load balancer.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elb.html#ElasticLoadBalancing.Client.register_instances_with_load_balancer)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#register_instances_with_load_balancer)
         """
 
     def remove_tags(
-        self, *, LoadBalancerNames: List[str], Tags: List[TagKeyOnlyTypeDef]
+        self, *, LoadBalancerNames: List[str], Tags: List["TagKeyOnlyTypeDef"]
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/elb.html#ElasticLoadBalancing.Client.remove_tags)
+        Removes one or more tags from the specified load balancer.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elb.html#ElasticLoadBalancing.Client.remove_tags)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#remove_tags)
         """
 
@@ -335,7 +402,9 @@ class ElasticLoadBalancingClient:
         self, *, LoadBalancerName: str, LoadBalancerPort: int, SSLCertificateId: str
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/elb.html#ElasticLoadBalancing.Client.set_load_balancer_listener_ssl_certificate)
+        Sets the certificate that terminates the specified listener's SSL connections.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elb.html#ElasticLoadBalancing.Client.set_load_balancer_listener_ssl_certificate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#set_load_balancer_listener_ssl_certificate)
         """
 
@@ -343,7 +412,10 @@ class ElasticLoadBalancingClient:
         self, *, LoadBalancerName: str, InstancePort: int, PolicyNames: List[str]
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/elb.html#ElasticLoadBalancing.Client.set_load_balancer_policies_for_backend_server)
+        Replaces the set of policies associated with the specified port on which the EC2
+        instance is listening with a new set of policies.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elb.html#ElasticLoadBalancing.Client.set_load_balancer_policies_for_backend_server)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#set_load_balancer_policies_for_backend_server)
         """
 
@@ -351,7 +423,10 @@ class ElasticLoadBalancingClient:
         self, *, LoadBalancerName: str, LoadBalancerPort: int, PolicyNames: List[str]
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/elb.html#ElasticLoadBalancing.Client.set_load_balancer_policies_of_listener)
+        Replaces the current set of policies for the specified load balancer port with
+        the specified set of policies.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elb.html#ElasticLoadBalancing.Client.set_load_balancer_policies_of_listener)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#set_load_balancer_policies_of_listener)
         """
 
@@ -360,7 +435,8 @@ class ElasticLoadBalancingClient:
         self, operation_name: Literal["describe_account_limits"]
     ) -> DescribeAccountLimitsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/elb.html#ElasticLoadBalancing.Paginator.DescribeAccountLimits)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/paginators.html#describeaccountlimitspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elb.html#ElasticLoadBalancing.Paginator.DescribeAccountLimits)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/paginators.html#describeaccountlimitspaginator)
         """
 
     @overload
@@ -368,7 +444,8 @@ class ElasticLoadBalancingClient:
         self, operation_name: Literal["describe_load_balancers"]
     ) -> DescribeLoadBalancersPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/elb.html#ElasticLoadBalancing.Paginator.DescribeLoadBalancers)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/paginators.html#describeloadbalancerspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elb.html#ElasticLoadBalancing.Paginator.DescribeLoadBalancers)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/paginators.html#describeloadbalancerspaginator)
         """
 
     @overload
@@ -376,7 +453,8 @@ class ElasticLoadBalancingClient:
         self, waiter_name: Literal["any_instance_in_service"]
     ) -> AnyInstanceInServiceWaiter:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/elb.html#ElasticLoadBalancing.Waiter.any_instance_in_service)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/waiters.html#anyinstanceinservicewaiter)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elb.html#ElasticLoadBalancing.Waiter.AnyInstanceInService)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/waiters.html#anyinstanceinservicewaiter)
         """
 
     @overload
@@ -384,11 +462,13 @@ class ElasticLoadBalancingClient:
         self, waiter_name: Literal["instance_deregistered"]
     ) -> InstanceDeregisteredWaiter:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/elb.html#ElasticLoadBalancing.Waiter.instance_deregistered)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/waiters.html#instancederegisteredwaiter)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elb.html#ElasticLoadBalancing.Waiter.InstanceDeregistered)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/waiters.html#instancederegisteredwaiter)
         """
 
     @overload
     def get_waiter(self, waiter_name: Literal["instance_in_service"]) -> InstanceInServiceWaiter:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/elb.html#ElasticLoadBalancing.Waiter.instance_in_service)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/waiters.html#instanceinservicewaiter)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elb.html#ElasticLoadBalancing.Waiter.InstanceInService)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/waiters.html#instanceinservicewaiter)
         """
